==> openshift-model-6.6.0-sources.jar: io/fabric8/openshift/api/model/GenericWebHookCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GenericWebHookCauseFluentImpl<A extends GenericWebHookCauseFluent<A>> extends BaseFluent<A> implements GenericWebHookCauseFluent<A>{
  public GenericWebHookCauseFluentImpl() {
  }
  public GenericWebHookCauseFluentImpl(GenericWebHookCause instance) {
    this.withRevision(instance.getRevision()); 
    this.withSecret(instance.getSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private SourceRevisionBuilder revision;
  private String secret;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRevision instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceRevision getRevision() {
    return this.revision!=null ?this.revision.build():null;
  }
  public SourceRevision buildRevision() {
    return this.revision!=null ?this.revision.build():null;
  }
  public A withRevision(SourceRevision revision) {
    _visitables.get("revision").remove(this.revision);
    if (revision!=null){ this.revision= new SourceRevisionBuilder(revision); _visitables.get("revision").add(this.revision);} else { this.revision = null; _visitables.get("revision").remove(this.revision); } return (A) this;
  }
  public Boolean hasRevision() {
    return this.revision != null;
  }
  public GenericWebHookCauseFluent.RevisionNested<A> withNewRevision() {
    return new GenericWebHookCauseFluentImpl.RevisionNestedImpl();
  }
  public GenericWebHookCauseFluent.RevisionNested<A> withNewRevisionLike(SourceRevision item) {
    return new GenericWebHookCauseFluentImpl.RevisionNestedImpl(item);
  }
  public GenericWebHookCauseFluent.RevisionNested<A> editRevision() {
    return withNewRevisionLike(getRevision());
  }
  public GenericWebHookCauseFluent.RevisionNested<A> editOrNewRevision() {
    return withNewRevisionLike(getRevision() != null ? getRevision(): new SourceRevisionBuilder().build());
  }
  public GenericWebHookCauseFluent.RevisionNested<A> editOrNewRevisionLike(SourceRevision item) {
    return withNewRevisionLike(getRevision() != null ? getRevision(): item);
  }
  public String getSecret() {
    return this.secret;
  }
  public A withSecret(String secret) {
    this.secret=secret; return (A) this;
  }
  public Boolean hasSecret() {
    return this.secret != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GenericWebHookCauseFluentImpl that = (GenericWebHookCauseFluentImpl) o;
    if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
    if (secret != null ? !secret.equals(that.secret) :that.secret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(revision,  secret,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (revision != null) { sb.append("revision:"); sb.append(revision + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RevisionNestedImpl<N> extends SourceRevisionFluentImpl<GenericWebHookCauseFluent.RevisionNested<N>> implements GenericWebHookCauseFluent.RevisionNested<N>,Nested<N>{
    RevisionNestedImpl(SourceRevision item) {
      this.builder = new SourceRevisionBuilder(this, item);
    }
    RevisionNestedImpl() {
      this.builder = new SourceRevisionBuilder(this);
    }
    SourceRevisionBuilder builder;
    public N and() {
      return (N) GenericWebHookCauseFluentImpl.this.withRevision(builder.build());
    }
    public N endRevision() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/GenericWebHookCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GenericWebHookCauseFluentImpl<A extends GenericWebHookCauseFluent<A>> extends BaseFluent<A> implements GenericWebHookCauseFluent<A>{
  public GenericWebHookCauseFluentImpl() {
  }
  public GenericWebHookCauseFluentImpl(GenericWebHookCause instance) {
    if (instance != null) {
      this.withRevision(instance.getRevision());
      this.withSecret(instance.getSecret());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SourceRevisionBuilder revision;
  private String secret;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRevision instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceRevision getRevision() {
    return this.revision!=null ?this.revision.build():null;
  }
  public SourceRevision buildRevision() {
    return this.revision!=null ?this.revision.build():null;
  }
  public A withRevision(SourceRevision revision) {
    _visitables.get("revision").remove(this.revision);
    if (revision!=null){ this.revision= new SourceRevisionBuilder(revision); _visitables.get("revision").add(this.revision);} else { this.revision = null; _visitables.get("revision").remove(this.revision); } return (A) this;
  }
  public Boolean hasRevision() {
    return this.revision != null;
  }
  public GenericWebHookCauseFluentImpl.RevisionNested<A> withNewRevision() {
    return new GenericWebHookCauseFluentImpl.RevisionNestedImpl();
  }
  public GenericWebHookCauseFluentImpl.RevisionNested<A> withNewRevisionLike(SourceRevision item) {
    return new GenericWebHookCauseFluentImpl.RevisionNestedImpl(item);
  }
  public GenericWebHookCauseFluentImpl.RevisionNested<A> editRevision() {
    return withNewRevisionLike(getRevision());
  }
  public GenericWebHookCauseFluentImpl.RevisionNested<A> editOrNewRevision() {
    return withNewRevisionLike(getRevision() != null ? getRevision(): new SourceRevisionBuilder().build());
  }
  public GenericWebHookCauseFluentImpl.RevisionNested<A> editOrNewRevisionLike(SourceRevision item) {
    return withNewRevisionLike(getRevision() != null ? getRevision(): item);
  }
  public String getSecret() {
    return this.secret;
  }
  public A withSecret(String secret) {
    this.secret=secret; return (A) this;
  }
  public Boolean hasSecret() {
    return this.secret != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GenericWebHookCauseFluentImpl that = (GenericWebHookCauseFluentImpl) o;
    if (!java.util.Objects.equals(revision, that.revision)) return false;

    if (!java.util.Objects.equals(secret, that.secret)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(revision,  secret,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (revision != null) { sb.append("revision:"); sb.append(revision + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RevisionNestedImpl<N> extends SourceRevisionFluentImpl<GenericWebHookCauseFluentImpl.RevisionNested<N>> implements GenericWebHookCauseFluentImpl.RevisionNested<N>,Nested<N>{
    RevisionNestedImpl(SourceRevision item) {
      this.builder = new SourceRevisionBuilder(this, item);
    }
    RevisionNestedImpl() {
      this.builder = new SourceRevisionBuilder(this);
    }
    SourceRevisionBuilder builder;
    public N and() {
      return (N) GenericWebHookCauseFluentImpl.this.withRevision(builder.build());
    }
    public N endRevision() {
      return and();
    }
    
  }
  
}
